==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/circles/l10n/sk.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Kruhy",
    "Circles' files" : "Súbory kruhu",
    "Select circles to filter by" : "Vyberte okruhy, ktoré chcete filtrovať",
    "No circles found" : "Nenašli sa žiadne kruhy",
    "Please select circles to filter by" : "Vyberte okruhy, ktoré chcete filtrovať",
    "No files found for the selected circles" : "Pre vybrané okruhy neboli nájdené žiadne súbory",
    "You created the circle {circle}" : "Vytvorili ste kruh {circle}",
    "{author} created the circle {circle}" : "{author} vytvoril kruh {circle}",
    "You deleted {circle}" : "Vymazali ste {circle}",
    "{author} deleted {circle}" : "{author} zmazal {circle}",
    "You linked {group} to {circle}" : "Pripojili ste {group} k {circle}",
    "{group} has been linked to {circle} by {author}" : "{author} pripojil {group} k {circle}",
    "You unlinked {group} from {circle}" : "Odpojili ste {group} z {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} z {circle} odpojil(a) {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Úroveň prepojenej skupiny {group} v {circle} ste zmenili na %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} zmenil(a) úroveň pripojenej skupiny {group} v {circle} na %1$s",
    "You sent a request to link {circle} with {remote}" : "Poslali ste požiadavku na prepojenie {circle} s {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} poslal(a) požiadavku na prepojenie {circle} s {remote}",
    "{remote} requested a link with {circle}" : "{remote} požiadal(a) o spojenie s {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Požiadavka o prepojenie  {circle} s {remote} bola zrušená",
    "The request to link {remote} with {circle} has been canceled remotely" : "Požiadavka o prepojenie {remote} s {circle} bola zrušená",
    "The request to link {circle} with {remote} has been accepted" : "Požiadavka o pripojenie {circle} s {remote} bola prijatá",
    "You dismissed the request to link {remote} with {circle}" : "Zrušili ste požiadavku o prepojenie {remote} s {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} zrušil(a) požiadavku o prepojenie {remote} s {circle}",
    "You canceled the request to link {circle} with {remote}" : "Odvolali ste svoju požiadavku o prepojenie {circle} s {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} odvolal(a) požiadavku o prepojenie {circle} s {remote}",
    "You accepted the request to link {remote} with {circle}" : "Prijali ste požiadavku o prepojenie {remote} s {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} prijal(a) požiadavku o prepojenie {remote} s {circle}",
    "A link between {circle} and {remote} is now up and running" : "Prepojenie medzi {circle} a {remote} je zapnuté a funguje",
    "The link between {circle} and {remote} has been shutdown remotely" : "Prepojenie medzi {circle} a {remote} bolo ukončené náprotivkom",
    "You closed the link between {circle} and {remote}" : "Zatvorili ste prepojenie medzi {circle} a {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} zatvoril(a) prepojenie medzi {circle} a {remote}",
    "You joined {circle}" : "Pripojili ste sa ku kruhu {circle}",
    "{member} joined {circle}" : "{member} sa pripojil o kruhu {circle}",
    "You accepted the invitation to join {circle}" : "Prijali ste pozvanie k pripojeniu k {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} prijal(a) pozvanie k pripojeniu k {circle}",
    "You added {member} as member to {circle}" : "Pridali ste {member} do {circle}",
    "You have been added as member to {circle} by {author}" : "{author} vás pridal(a) do {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} pridal(a) {member} do {circlel}",
    "You added {external} to {circle}" : "Pridali ste {external} do {circle}",
    "{external} has been added to {circle} by {author}" : "{author} pridal(a) {external} do {circle}",
    "You accepted {member}'s request to join {circle}" : "Prijali ste požiadavku od {member} na pripojenie k {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Vaša žiadosť o pripojenie do kruhu {circle} bola prijatá používateľom {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} prijal(a) požiadavku {member} na pripojenie k {circle}",
    "You left {circle}" : "Opustili ste kruh {circle}",
    "{member} left {circle}" : "Používateľ {member} odišiel z kruhu {circle}",
    "You declined the invitation to join {circle}" : "Odmietli ste pozvánku pre pripojenie ku kruhu {circle}",
    "{member} declined an invitation to join {circle}" : "Používateľ {member} odmietol pozvánku pre pripojenie sa ku kruhu {circle}",
    "You cancelled your request to join {circle}" : "Zrušili ste vašu požiadavku o pripojenie k {circle}",
    "{member} cancelled his request to join {circle}" : "{member} zrušil(a) svoju požiadavku na pripojenie k {circle}",
    "You removed {member} from {circle}" : "Odstranili ste {member} z {circle}",
    "You have been removed from {circle} by {author}" : "{author} vás odstránil(a) z {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} odstránil(a) {member} z {circle}",
    "You removed {external} from {circle}" : "Odstránili ste {external} z {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} odstránil(a) {external} z {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Zrušili ste pozvanie {member} na pripojenie k {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} zrušil(a) vašu pozvánku na pripojenie k {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} zrušil(a) pozvánku {member} na pripojenie k {circle}",
    "You dismissed {member}'s request to join {circle}" : "Odmietli ste požiadavku {member} na pripojenie k {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} odmietol(a) vašu požiadavku na pripojenie k {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} odmietol požiadavku {member} na pripojenie k {circle}",
    "You invited {member} to join {circle}" : "Pozvali ste {member} na pripojenie k {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vás pozval(a) k pripojeniu k {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} pozval(a) {member} k pripojeniu k {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Zmenili ste úroveň {member} v {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} zmenil(a) vašu úroveň v {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} zmenil(a) úroveň {member} v {circle} na %1$s",
    "You sent a request to join {circle}" : "Odoslali ste požiadavku na pripojenie k {circle}",
    "{member} sent a request to join {circle}" : "{member} odoslal(a) požiadavku na pripojenie k {circle}",
    "You are the new owner of {circle}" : "Ste novým vlastníkom {circle}",
    "{member} is the new owner of {circle}" : "{member} je novým vlastníkom {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Pri udalostiach odohrávajúcich sa v <strong>okrhu</strong>, ktorého ste členom/členkou",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Dôležité udalosti v <strong>okruhu</strong>, ktorý moderujete",
    "On global events happening in any <strong>Circle</strong>" : "Pri globálnych udalostiach, ktoré sa odohrávajú v ktoromkoľvek <strong>okruhu</strong>",
    "Single" : "Slobodný",
    "Personal" : "Osobný",
    "System" : "Systém",
    "Visible" : "Viditeľné",
    "Open" : "Otvoriť",
    "Invite" : "Pozvať",
    "Join Request" : "Žiadosť o pripojenie",
    "Friends" : "Priatelia",
    "Password Protected" : "Chránené heslom",
    "No Owner" : "Žiadny vlastník",
    "Hidden" : "Skryté",
    "Backend" : "Backend",
    "Local" : "Lokálny",
    "Root" : "Koreň",
    "Circle Invite" : "Pozvať do kruhu",
    "Federated" : "Združený",
    "Mount point" : "Prípojný bod",
    "Nextcloud Account" : "Účet Nextcloud",
    "Nextcloud Group" : "Skupina Nextcloud",
    "Email Address" : "E-mailová adresa",
    "Contact" : "Kontakt",
    "Circle" : "Kruh",
    "Nextcloud App" : "Aplikácia Nextcloud",
    "Member" : "Člen",
    "Moderator" : "Moderátor",
    "Admin" : "Administrátor",
    "Owner" : "Vlastník",
    "%s shared »%s« with you." : "%s vám sprístupnil »%s«",
    "%s shared »%s« with \"%s\"." : "%s zdieľané »%s« s \"%s\".",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s s vami zdieľa »%2$s«.\nUž ste mali dostať e-mail s odkazom na prístup k ním.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s s vami zdieľa »%2$s«. Už ste mali dostať e-mail s odkazom na prístup k ním.",
    "Password to access »%1$s« shared to you by %2$s" : "Heslo pre prístup k »%1$s« Vám sprístupnil %2$s",
    "Password to access »%s«" : "Heslo pre prístup k »%s«",
    "It is protected with the following password:" : "Je chránené nasledovným heslom:",
    "%1$s via %2$s" : "%1$s cez %2$s",
    "Click the button below to open it." : "Stlačte tlačidlo nižšie pre otvorenie.",
    "Open »%s«" : "Otvoriť »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s s vami zdieľa niekoľko súborov.\nUž ste mali dostať e-mail s odkazom na prístup k ním.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s s vami zdieľa niekoľko súborov. Už ste mali dostať e-mail s odkazom na prístup k ním.",
    "Password to access files shared to you by %1$s" : "Heslo pre prístup k súborom, ktoré s vami zdieľa %1$s",
    "Password to access files" : "Heslo pre prístup k súborom",
    "%s shared multiple files with \"%s\"." : "%s zdieľa viacero súborov s \"%s\".",
    "%s shared multiple files with you." : "%s s vami zdieľa súbory.",
    "Boot up" : "Štart",
    "Initialisation Nextcloud" : "Inicializácia Nextcloudu",
    "Initialisation Circles App" : "Inicializácia Aplikácie Kruhy",
    "Fresh installation status" : "Stav čistej inštalácie",
    "Building Local Database" : "Vytváram Lokálnu Databázu",
    "Testing Basic Circle Creation" : "Testujem základné pridávanie Kruhov",
    "Adding local users and moderators" : "Pridávam lokálnych užívateľov a moderátorov",
    "Circle not found" : "Kruh sa nenašiel",
    "Circle not found " : "Okruh nebol nájdený ",
    "A circle with that name exists" : "Kruh s týmto názvom existuje",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Nemôžete použiť aplikáciu Kruhy, pokiaľ administrátor nepovolí aspoň jeden typ kruhov",
    "This member does not exist" : "Tento používateľ neexistuje",
    "This account is already a member of the circle" : "Tento užívateľ už je členom kruhu",
    "Federated link not found" : "Združené prepojenie sa nenašlo",
    "This feature is not available for personal circles" : "Táto funkcia nie je k dispozícii pre osobné kruhy",
    "The circle is not federated" : "Okruh nie je združený",
    "You cannot join this circle" : "Nemôžete sa pripojiť k tomuto kruhu",
    "This member is not a moderator" : "Tento člen nie je moderátor",
    "Insufficient privileges" : "Nedostatočné oprávnenia",
    "This member is the owner of the circle" : "Tento člen je vlastník kruhu",
    "Level cannot be changed for this type of member" : "Pre tento typ člena, úroveň nemôže byť zmenená.",
    "You are already a member of this circle" : "Už ste členom tohto kruhu",
    "You have been blocked from this circle" : "Boli ste zablokovaný z tohto kruhu",
    "The account is already a member of this circle" : "Tento užívateľ už je členom kruhu",
    "The account has already been invited into this circle" : "Užívateľ už bol pozvaný do tohto kruhu",
    "%s (Circle owned by %s)" : "%s (Kruh vlastnený %s)",
    "You are now a member of the Circle \"%2$s\"" : "Teraz ste členom okruhu \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Do okruhu \"%2$s\" vás pozval(a) %1$s",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "Požiadavku, stať sa členom okruhu \"%2$s\", zaslal(a) %1$s",
    "Accept" : "Prijať",
    "Refuse" : "Odmietnuť",
    "Leave the circle" : "Opustiť okruh",
    "%s" : "%s",
    "Personal Circle" : "Osobný kruh",
    "%s owned by %s" : "%s vlastnené %s",
    "You need a specify a type of circle" : "Musíte špecifikovať typ kruhu",
    "This member is not the owner of the circle" : "Tento člen nie je vlastník kruhu",
    "This member is not an admin of the circle" : "Tento člen nie je správcom okruhu",
    "Group contains too many members" : "Skupina obsahuje priveľa členov",
    "This group does not exist" : "Táto skupina neexistuje",
    "This group is already linked to the circle" : "Táto skupina je už s kruhom prepojená",
    "You cannot edit level in a personal circle" : "Úroveň osobného kruhu sa nedá upraviť",
    "Group cannot be set as owner of a circle" : "Skupina nemôže byť nastavená ako vlastník okruhu",
    "now" : "teraz",
    "This account does not exist" : "Tento účet neexistuje",
    "Email format is not valid" : "Nesprávny formát e-mailu",
    "This contact is not available" : "Tento kontakt je nedostupný",
    "You have no permission to create a new circle" : "Nemáte oprávnenia pre vytváranie nových kruhov",
    "%s shared a file with \"%s\"." : "%s zozdieľal súbor s \"%s\".",
    "%s shared a file with you." : "%s vám nazdieľal súbor.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s s vami zdieľa nejaký obsah. Už ste mali dostať e-mail so samostatným odkazom na prístup k nemu.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s s vami zdieľa nejaký obsah. Už ste mali dostať e-mail s odkazom na prístup k ním.",
    "Password to access content shared with you by %1$s" : "Heslo pre prístup k obsahu, ktorý s vami zdieľa %1$s",
    "Password to access content" : "Heslo pre prístup k obsahu",
    "This item is already shared with this circle" : "Táto položka je už zdieľaná s týmto kruhom",
    "Could not find share" : "Nebolo možné nájsť sprístupnenie",
    "Bring cloud-users closer together." : "Zblížte užívateľov cloudu.",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Kruhy umožňujú vašim užívateľom vytvárať ich vlastné skupiny užívateľov/kolegov/priateľov.\nTieto skupiny užívateľov (alebo \"kruhov\") môžu buť potom používané akoukoľvek inou aplikáciou pre potreby zdieľania.",
    "No files in here" : "Nie sú tu žiadne súbory",
    "No entries found in this folder" : "V tomto priečinku sa nič nenašlo",
    "Name" : "Názov",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "Nextcloud User" : "Užívateľ Nextcloud",
    "This user is already a member of the circle" : "Tento používateľ už je členom kruhu",
    "The user is already a member of this circle" : "Používateľ už je členom tohto kruhu",
    "The user has already been invited into this circle" : "Používateľ už bol pozvaný do tohto kruhu",
    "This user does not exist" : "Vybraný používateľ neexistuje",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Kruhy umožňujú vašim užívateľom vytvárať ich vlastné skupiny užívateľov/kolegov/priateľov.\nTieto skupiny užívateľov (alebo \"kruhov\") môžu buť potom používané akoukoľvek inou aplikáciou pre potreby zdieľania."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-28.0.5.tar.bz2: nextcloud/apps/circles/l10n/sk.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Tímy",
    "You deleted {circle}" : "Vymazali ste {circle}",
    "{author} deleted {circle}" : "{author} zmazal {circle}",
    "You removed {member} from {circle}" : "Odstranili ste {member} z {circle}",
    "You joined {circle}" : "Pripojili ste sa ku kruhu {circle}",
    "{member} joined {circle}" : "{member} sa pripojil o kruhu {circle}",
    "You accepted the invitation to join {circle}" : "Prijali ste pozvanie k pripojeniu k {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} prijal(a) pozvanie k pripojeniu k {circle}",
    "You added {member} as member to {circle}" : "Pridali ste {member} do {circle}",
    "You have been added as member to {circle} by {author}" : "{author} vás pridal(a) do {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} pridal(a) {member} do {circlel}",
    "You added {external} to {circle}" : "Pridali ste {external} do {circle}",
    "{external} has been added to {circle} by {author}" : "{author} pridal(a) {external} do {circle}",
    "You accepted {member}'s request to join {circle}" : "Prijali ste požiadavku od {member} na pripojenie k {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Vaša žiadosť o pripojenie do kruhu {circle} bola prijatá používateľom {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} prijal(a) požiadavku {member} na pripojenie k {circle}",
    "You left {circle}" : "Opustili ste kruh {circle}",
    "{member} left {circle}" : "Používateľ {member} odišiel z kruhu {circle}",
    "You declined the invitation to join {circle}" : "Odmietli ste pozvánku pre pripojenie ku kruhu {circle}",
    "{member} declined an invitation to join {circle}" : "Používateľ {member} odmietol pozvánku pre pripojenie sa ku kruhu {circle}",
    "You cancelled your request to join {circle}" : "Zrušili ste vašu požiadavku o pripojenie k {circle}",
    "You have been removed from {circle} by {author}" : "{author} vás odstránil(a) z {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} odstránil(a) {member} z {circle}",
    "You removed {external} from {circle}" : "Odstránili ste {external} z {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} odstránil(a) {external} z {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Zrušili ste pozvanie {member} na pripojenie k {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} zrušil(a) vašu pozvánku na pripojenie k {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} zrušil(a) pozvánku {member} na pripojenie k {circle}",
    "You dismissed {member}'s request to join {circle}" : "Odmietli ste požiadavku {member} na pripojenie k {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} odmietol(a) vašu požiadavku na pripojenie k {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} odmietol požiadavku {member} na pripojenie k {circle}",
    "You invited {member} to join {circle}" : "Pozvali ste {member} na pripojenie k {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vás pozval(a) k pripojeniu k {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} pozval(a) {member} k pripojeniu k {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Zmenili ste úroveň {member} v {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} zmenil(a) vašu úroveň v {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} zmenil(a) úroveň {member} v {circle} na %1$s",
    "You sent a request to join {circle}" : "Odoslali ste požiadavku na pripojenie k {circle}",
    "{member} sent a request to join {circle}" : "{member} odoslal(a) požiadavku na pripojenie k {circle}",
    "You are the new owner of {circle}" : "Ste novým vlastníkom {circle}",
    "{member} is the new owner of {circle}" : "{member} je novým vlastníkom {circle}",
    "Shared to Circles" : "Zdieľané v kruhoch",
    "Single" : "Slobodný",
    "Personal" : "Osobný",
    "System" : "Systém",
    "Visible" : "Viditeľné",
    "Open" : "Otvoriť",
    "Invite" : "Pozvať",
    "Friends" : "Priatelia",
    "Password protected" : "Chránené heslom",
    "No Owner" : "Žiadny vlastník",
    "Hidden" : "Skryté",
    "Backend" : "Backend",
    "Local" : "Lokálny",
    "Root" : "Koreň",
    "Federated" : "Združený",
    "Mount point" : "Prípojný bod",
    "Nextcloud Account" : "Účet Nextcloud",
    "Nextcloud Group" : "Skupina Nextcloud",
    "Email address" : "E-mailová adresa",
    "Contact" : "Kontakt",
    "Circle" : "Kruh",
    "Nextcloud App" : "Aplikácia Nextcloud",
    "Member" : "Člen",
    "Moderator" : "Moderátor",
    "Admin" : "Administrátor",
    "Owner" : "Vlastník",
    "%s shared »%s« with you." : "%s vám sprístupnil »%s«",
    "%s shared »%s« with \"%s\"." : "%s zdieľané »%s« s \"%s\".",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s s vami zdieľa »%2$s«.\nUž ste mali dostať e-mail s odkazom na prístup k ním.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s s vami zdieľa »%2$s«. Už ste mali dostať e-mail s odkazom na prístup k ním.",
    "Password to access »%1$s« shared to you by %2$s" : "Heslo pre prístup k »%1$s« Vám sprístupnil %2$s",
    "Password to access »%s«" : "Heslo pre prístup k »%s«",
    "It is protected with the following password:" : "Je chránené nasledovným heslom:",
    "%1$s via %2$s" : "%1$s cez %2$s",
    "Click the button below to open it." : "Stlačte tlačidlo nižšie pre otvorenie.",
    "Open »%s«" : "Otvoriť »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s s vami zdieľa niekoľko súborov.\nUž ste mali dostať e-mail s odkazom na prístup k ním.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s s vami zdieľa niekoľko súborov. Už ste mali dostať e-mail s odkazom na prístup k ním.",
    "Password to access files shared to you by %1$s" : "Heslo pre prístup k súborom, ktoré s vami zdieľa %1$s",
    "Password to access files" : "Heslo pre prístup k súborom",
    "%s shared multiple files with \"%s\"." : "%s zdieľa viacero súborov s \"%s\".",
    "%s shared multiple files with you." : "%s s vami zdieľa súbory.",
    "Boot up" : "Štart",
    "Fresh installation status" : "Stav čistej inštalácie",
    "Building Local Database" : "Vytváram Lokálnu Databázu",
    "Testing Basic Circle Creation" : "Testujem základné pridávanie Kruhov",
    "Adding local users and moderators" : "Pridávam lokálnych užívateľov a moderátorov",
    "Files" : "Súbory",
    "This feature is not available for personal circles" : "Táto funkcia nie je k dispozícii pre osobné kruhy",
    "This member is not a moderator" : "Tento člen nie je moderátor",
    "Insufficient privileges" : "Nedostatočné oprávnenia",
    "This member does not exist" : "Tento používateľ neexistuje",
    "Level cannot be changed for this type of member" : "Pre tento typ člena, úroveň nemôže byť zmenená.",
    "You are already a member of this circle" : "Už ste členom tohto kruhu",
    "You have been blocked from this circle" : "Boli ste zablokovaný z tohto kruhu",
    "The account is already a member of this circle" : "Tento užívateľ už je členom kruhu",
    "The account has already been invited into this circle" : "Užívateľ už bol pozvaný do tohto kruhu",
    "You are now a member of the Circle \"%2$s\"" : "Teraz ste členom kruhu \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Do kruhu \"%2$s\" vás pozval(a) %1$s",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "Požiadavku, stať sa členom kruhu \"%2$s\", zaslal(a) %1$s",
    "Accept" : "Prijať",
    "Refuse" : "Odmietnuť",
    "Leave the circle" : "Opustiť kruh",
    "%s" : "%s",
    "%s owned by %s" : "%s vlastnené %s",
    "%s shared a file with \"%s\"." : "%s zozdieľal súbor s \"%s\".",
    "%s shared a file with you." : "%s vám nazdieľal súbor.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s s vami zdieľa nejaký obsah. Už ste mali dostať e-mail so samostatným odkazom na prístup k nemu.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s s vami zdieľa nejaký obsah. Už ste mali dostať e-mail s odkazom na prístup k ním.",
    "Password to access content shared with you by %1$s" : "Heslo pre prístup k obsahu, ktorý s vami zdieľa %1$s",
    "Password to access content" : "Heslo pre prístup k obsahu",
    "Bring cloud-users closer together." : "Zblížte používateľov cloudu.",
    "No files in here" : "Nie sú tu žiadne súbory",
    "No entries found in this folder" : "V tomto priečinku sa nič nenašlo",
    "Name" : "Názov",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "Circles" : "Kruhy",
    "Circles' files" : "Súbory kruhu",
    "Select circles to filter by" : "Vyberte kruhy, ktoré chcete filtrovať",
    "No circles found" : "Nenašli sa žiadne kruhy",
    "Please select circles to filter by" : "Vyberte kruhy, ktoré chcete filtrovať",
    "No files found for the selected circles" : "Pre vybrané kruhy neboli nájdené žiadne súbory",
    "You created the circle {circle}" : "Vytvorili ste kruh {circle}",
    "{author} created the circle {circle}" : "{author} vytvoril kruh {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Pri udalostiach odohrávajúcich sa v <strong>okrhu</strong>, ktorého ste členom/členkou",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Dôležité udalosti v <strong>kruhu</strong>, ktorý moderujete",
    "On global events happening in any <strong>Circle</strong>" : "Pri globálnych udalostiach, ktoré sa odohrávajú v ktoromkoľvek <strong>kruhu</strong>",
    "Join Request" : "Žiadosť o pripojenie",
    "Password Protected" : "Chránené heslom",
    "Circle Invite" : "Pozvať do kruhu",
    "Email Address" : "E-mailová adresa",
    "Circle not found" : "Kruh sa nenašiel",
    "Circle not found " : "Kruh nebol nájdený ",
    "This account is already a member of the circle" : "Tento užívateľ už je členom kruhu",
    "Federated link not found" : "Združené prepojenie sa nenašlo",
    "The circle is not federated" : "Kruh nie je združený",
    "You cannot join this circle" : "Nemôžete sa pripojiť k tomuto kruhu",
    "This member is the owner of the circle" : "Tento člen je vlastník kruhu",
    "%s (Circle owned by %s)" : "%s (Kruh vlastnený %s)",
    "Personal Circle" : "Osobný kruh",
    "You need a specify a type of circle" : "Musíte špecifikovať typ kruhu",
    "A circle with that name exists" : "Kruh s týmto názvom existuje",
    "This member is not the owner of the circle" : "Tento člen nie je vlastník kruhu",
    "This member is not an admin of the circle" : "Tento člen nie je správcom kruhu",
    "Group contains too many members" : "Skupina obsahuje priveľa členov",
    "This group does not exist" : "Táto skupina neexistuje",
    "This group is already linked to the circle" : "Táto skupina je už s kruhom prepojená",
    "You cannot edit level in a personal circle" : "Úroveň osobného kruhu sa nedá upraviť",
    "Group cannot be set as owner of a circle" : "Skupina nemôže byť nastavená ako vlastník kruhu",
    "now" : "teraz",
    "This account does not exist" : "Tento účet neexistuje",
    "Email format is not valid" : "Nesprávny formát e-mailu",
    "This contact is not available" : "Tento kontakt je nedostupný",
    "You have no permission to create a new circle" : "Nemáte oprávnenia pre vytváranie nových kruhov",
    "This item is already shared with this circle" : "Táto položka je už zdieľaná s týmto kruhom",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Kruhy umožňujú vašim užívateľom vytvárať ich vlastné skupiny užívateľov/kolegov/priateľov.\nTieto skupiny užívateľov (alebo \"kruhov\") môžu buť potom používané akoukoľvek inou aplikáciou pre potreby zdieľania."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
